@@ -3,21 +3,21 @@ package Perinci::To::DocBase::I18N;
 use base 'Locale::Maketext';
 use Locale::Maketext::Lexicon;
 
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 1;
-# ABSTRACT: Project class for Perinci::To::* document generators
+# ABSTRACT: Project class for Perinci::To::DocBase
 
 __END__
 =pod
 
 =head1 NAME
 
-Perinci::To::DocBase::I18N - Project class for Perinci::To::* document generators
+Perinci::To::DocBase::I18N - Project class for Perinci::To::DocBase
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 AUTHOR
 
